@@ -3,6 +3,9 @@
 # Copyright (c) ALT-F1 SPRL, Abdelkrim Boujraf. All rights reserved.
 # Licensed under the EUPL License, Version 1.2. See LICENSE in the project root for license information.
 
-from .altf1be_helpers import AltF1BeHelpers
+from .altf1be_helpers import AltF1BeHelpers, AltF1BeJSONHelpers
 
-__all__ = ["AltF1BeHelpers"]
\ No newline at end of file
+__all__ = [
+    "AltF1BeHelpers",
+    "AltF1BeJSONHelpers"
+]
