@@ -21,6 +21,7 @@ import glob
 import sys
 import re
 import os
+import json
 for dirname, _, filenames in os.walk('/kaggle/input'):
     for filename in filenames:
         print(os.path.join(dirname, filename))
@@ -33,6 +34,7 @@ MISSING_LIBRARY = -1
 
 logging.getLogger("urllib3").setLevel(logging.WARNING)
 
+
 class AltF1BeHelpers:
 
     @staticmethod
@@ -184,7 +186,7 @@ class AltF1BeHelpers:
                 input_directory, os.path.sep.join(directories))
         else:
             input_directory = os.path.join(os.path.abspath(
-                os.getcwd()), os.path.sep.join(directories)) # TODO: revise all codes. former code was this "output_directory", "data",
+                os.getcwd()), os.path.sep.join(directories))  # TODO: revise all codes. former code was this "output_directory", "data",
 
         return input_directory
 
@@ -221,7 +223,7 @@ class AltF1BeHelpers:
         msg = f"The log file is stored here: {filepath_log}"
         print(msg)
         logging.info(msg)
-        
+
         return filepath_log
 
     @staticmethod
@@ -256,9 +258,98 @@ if __name__ == "__main__":
         f'parse_requirements : {AltF1BeHelpers.parse_requirements("requirements.txt")}'
     )
 
-log_filename = AltF1BeHelpers.create_append_log_file(f"{os.path.basename(__file__)}.log")
+
+class AltF1BeJSONHelpers:
+    """ Simple helper to load, save and save with date time a JSON file
+
+    """
+    @property
+    def filename(self):
+        return self.__filename
+
+    @filename.setter
+    def filename(self, filename):
+        self.__filename = os.path.join(
+            # AltF1BeHelpers.output_directory(), # TODO remove this line to generalize the management of the files
+            filename
+        )
+
+    def __init__(self):
+        pass
+
+    def save_with_datetime(self, data, filename):
+        filename_path = os.path.dirname(filename)
+        filename = datetime.now().strftime(
+            f'%Y-%m-%d_%H-%M-%S-{os.path.basename(filename)}'
+        )
+        self.save(
+            data=data,
+            filename=os.path.join(
+                # AltF1BeHelpers.output_directory(
+                #     ['api']
+                # ),
+                filename_path,
+                filename
+            )
+        )
+
+    def save(self, data, filename=None):
+        """
+            store json file under filename/credentials by default
+        """
+        if (filename):
+            self.filename = filename
+
+        Path(os.path.dirname(self.filename)).mkdir(
+            parents=True, exist_ok=True)
+
+        with open(self.filename, 'w', encoding='utf-8') as f:
+            json.dump(json.loads(data), f, ensure_ascii=False, indent=4)
+
+    def load(self, filename):
+        if (filename):
+            self.filename = filename
+
+        with open(self.filename) as json_file:
+            data = json.load(json_file)
+        return data
+
+
+if __name__ == "__main__":
+    altF1BeJSONHelpers = AltF1BeJSONHelpers()
+    data = altF1BeJSONHelpers.load(
+        os.path.join(
+            os.path.dirname(__file__),
+            "data",
+            "altf1be_sample.json"
+        )
+    )
+    print(data)
+
+    data_str = json.dumps(data)
+    altF1BeJSONHelpers.save(
+        data_str,
+        os.path.join(
+            os.path.dirname(__file__),
+            "data",
+            "altf1be_sample_output.json"
+        )
+    )
+
+    altF1BeJSONHelpers.save_with_datetime(
+        data_str,
+        os.path.join(
+            os.path.dirname(__file__),
+            "data",
+            "altf1be_sample_with_date_time_output.json"
+        )
+    )
+
+
+log_filename = AltF1BeHelpers.create_append_log_file(
+    f"{os.path.basename(__file__)}.log")
 
 logging.basicConfig(
     filename=log_filename,
     level=logging.INFO
-)
\ No newline at end of file
+)
